@@ -1,21 +1,4 @@
 ##
-# This software was developed and / or modified by Raytheon Company,
-# pursuant to Contract DG133W-05-CQ-1067 with the US Government.
-#
-# U.S. EXPORT CONTROLLED TECHNICAL DATA
-# This software product contains export-restricted data whose
-# export/transfer/disclosure is restricted by U.S. law. Dissemination
-# to non-U.S. persons whether in the United States or abroad requires
-# an export license or other authorization.
-#
-# Contractor Name:        Raytheon Company
-# Contractor Address:     6825 Pine Street, Suite 340
-#                         Mail Stop B8
-#                         Omaha, NE 68106
-#                         402.291.0100
-#
-# See the AWIPS II Master Rights File ("Master Rights File.pdf") for
-# further licensing information.
 ##
 
 
@@ -41,20 +24,18 @@ __all__ = [
            ]
 
 import abc
-
-class IDataRequest(object):
+from six import with_metaclass
+class IDataRequest(with_metaclass(abc.ABCMeta, object)):
     """
     An IDataRequest to be submitted to the DataAccessLayer to retrieve data.
     """
-    __metaclass__ = abc.ABCMeta
 
     @abc.abstractmethod
     def setDatatype(self, datatype):
         """
         Sets the datatype of the request.
 
-        Args:
-                datatype: A string of the datatype, such as "grid", "radar", "gfe", "obs"
+        :param datatype: A string of the datatype, such as "grid", "radar", "gfe", "obs"
         """
         return
 
@@ -64,9 +45,8 @@ class IDataRequest(object):
         Adds an identifier to the request.  Identifiers are specific to the
         datatype being requested.
 
-        Args:
-                key: the string key of the identifier
-                value: the value of the identifier
+        :param key: the string key of the identifier
+        :param value: the value of the identifier
         """
         return
 
@@ -75,8 +55,7 @@ class IDataRequest(object):
         """
         Sets the parameters of data to request.
 
-        Args:
-                params: a list of strings of parameters to request
+        :param params: a list of strings of parameters to request
         """
         return
 
@@ -85,8 +64,7 @@ class IDataRequest(object):
         """
         Sets the levels of data to request.  Not all datatypes support levels.
 
-        Args:
-                levels: a list of strings of level abbreviations to request
+        :param levels: a list of strings of level abbreviations to request
         """
         return
 
@@ -97,8 +75,7 @@ class IDataRequest(object):
         the data returned for the request will be constrained to only the data
         within the envelope.
 
-        Args:
-                env: a shapely geometry
+        :param env: a shapely geometry
         """
         return
 
@@ -107,7 +84,6 @@ class IDataRequest(object):
         """
         Sets the location names of the request.
 
-        Args:
                 locationNames: a list of strings of location names to request
         """
         return
@@ -117,8 +93,7 @@ class IDataRequest(object):
         """
         Gets the datatype of the request
 
-        Returns:
-                the datatype set on the request
+        :returns: the datatype set on the request
         """
         return
 
@@ -127,8 +102,7 @@ class IDataRequest(object):
         """
         Gets the identifiers on the request
 
-        Returns:
-                a dictionary of the identifiers
+        :returns: a dictionary of the identifiers
         """
         return
 
@@ -137,8 +111,7 @@ class IDataRequest(object):
         """
         Gets the levels on the request
 
-        Returns:
-                a list of strings of the levels
+        :returns: a list of strings of the levels
         """
         return
 
@@ -147,8 +120,7 @@ class IDataRequest(object):
         """
         Gets the location names on the request
 
-        Returns:
-                a list of strings of the location names
+        :returns: a list of strings of the location names
         """
         return
 
@@ -157,29 +129,25 @@ class IDataRequest(object):
         """
         Gets the envelope on the request
 
-        Returns:
-                a rectangular shapely geometry
+        :returns: a rectangular shapely geometry
         """
         return
 
 
 
-class IData(object):
+class IData(with_metaclass(abc.ABCMeta, object)):
     """
     An IData representing data returned from the DataAccessLayer.
     """
-    __metaclass__ = abc.ABCMeta
 
     @abc.abstractmethod
     def getAttribute(self, key):
         """
         Gets an attribute of the data.
 
-        Args:
-                key: the key of the attribute
+        :param key: the key of the attribute
 
-        Returns:
-                the value of the attribute
+        :returns: the value of the attribute
         """
         return
 
@@ -188,8 +156,7 @@ class IData(object):
         """
         Gets the valid attributes for the data.
 
-        Returns:
-                a list of strings of the attribute names
+        :returns: a list of strings of the attribute names
         """
         return
 
@@ -198,8 +165,7 @@ class IData(object):
         """
         Gets the data time of the data.
 
-        Returns:
-                the data time of the data, or None if no time is associated
+        :returns: the data time of the data, or None if no time is associated
         """
         return
 
@@ -208,8 +174,7 @@ class IData(object):
         """
         Gets the level of the data.
 
-        Returns:
-                the level of the data, or None if no level is associated
+        :returns: the level of the data, or None if no level is associated
         """
         return
 
@@ -218,8 +183,7 @@ class IData(object):
         """
         Gets the location name of the data.
 
-        Returns:
-                the location name of the data, or None if no location name is
+        :returns: the location name of the data, or None if no location name is
                 associated
         """
         return
@@ -236,8 +200,7 @@ class IGridData(IData):
         """
         Gets the parameter of the data.
 
-        Returns:
-                the parameter of the data
+        :returns: the parameter of the data
         """
         return
 
@@ -246,8 +209,7 @@ class IGridData(IData):
         """
         Gets the unit of the data.
 
-        Returns:
-                the string abbreviation of the unit, or None if no unit is associated
+        :returns: the string abbreviation of the unit, or None if no unit is associated
         """
         return
 
@@ -256,8 +218,7 @@ class IGridData(IData):
         """
         Gets the grid data as a numpy array.
 
-        Returns:
-                a numpy array of the data
+        :returns: a numpy array of the data
         """
         return
 
@@ -266,8 +227,7 @@ class IGridData(IData):
         """
         Gets the lat/lon coordinates of the grid data.
 
-        Returns:
-            a tuple where the first element is a numpy array of lons, and the
+        :returns: a tuple where the first element is a numpy array of lons, and the
             second element is a numpy array of lats
         """
         return
@@ -284,8 +244,7 @@ class IGeometryData(IData):
         """
         Gets the geometry of the data.
 
-        Returns:
-                a shapely geometry
+        :returns: a shapely geometry
         """
         return
 
@@ -293,8 +252,7 @@ class IGeometryData(IData):
     def getParameters(self):
         """Gets the parameters of the data.
 
-        Returns:
-                a list of strings of the parameter names
+        :returns: a list of strings of the parameter names
         """
         return
 
@@ -303,11 +261,9 @@ class IGeometryData(IData):
         """
         Gets the string value of the specified param.
 
-        Args:
-                param: the string name of the param
+        :param param: the string name of the param
 
-        Returns:
-                the string value of the param
+        :returns: the string value of the param
         """
         return
 
@@ -316,11 +272,9 @@ class IGeometryData(IData):
         """
         Gets the number value of the specified param.
 
-        Args:
-                param: the string name of the param
+        :param param: the string name of the param
 
-        Returns:
-                the number value of the param
+        :returns: the number value of the param
         """
         return
 
@@ -329,11 +283,9 @@ class IGeometryData(IData):
         """
         Gets the unit of the specified param.
 
-        Args:
-                param: the string name of the param
+        :param param: the string name of the param
 
-        Returns:
-                the string abbreviation of the unit of the param
+        :returns: the string abbreviation of the unit of the param
         """
         return
 
@@ -342,12 +294,10 @@ class IGeometryData(IData):
         """
         Gets the type of the param.
 
-        Args:
-                param: the string name of the param
+        :param param: the string name of the param
 
-        Returns:
-                a string of the type of the parameter, such as
-                "STRING", "INT", "LONG", "FLOAT", or "DOUBLE"
+        :returns: a string of the type of the parameter, such as
+            "STRING", "INT", "LONG", "FLOAT", or "DOUBLE"
         """
         return
 
