@@ -1,21 +1,4 @@
 ##
-# This software was developed and / or modified by Raytheon Company,
-# pursuant to Contract DG133W-05-CQ-1067 with the US Government.
-#
-# U.S. EXPORT CONTROLLED TECHNICAL DATA
-# This software product contains export-restricted data whose
-# export/transfer/disclosure is restricted by U.S. law. Dissemination
-# to non-U.S. persons whether in the United States or abroad requires
-# an export license or other authorization.
-#
-# Contractor Name:        Raytheon Company
-# Contractor Address:     6825 Pine Street, Suite 340
-#                         Mail Stop B8
-#                         Omaha, NE 68106
-#                         402.291.0100
-#
-# See the AWIPS II Master Rights File ("Master Rights File.pdf") for
-# further licensing information.
 ##
 
 #
@@ -57,7 +40,7 @@ class ListenThread(threading.Thread):
         self.qs.topicSubscribe(self.topicName, self.receivedMessage)
 
     def receivedMessage(self, msg):
-        print "Received message"
+        print("Received message")
         self.nMessagesReceived += 1
         if self.waitSecond == 0:
             fmsg = open('/tmp/rawMessage', 'w')
@@ -66,20 +49,20 @@ class ListenThread(threading.Thread):
 
         while self.waitSecond < TIME_TO_SLEEP and not self.stopped:
             if self.waitSecond % 60 == 0:
-                print time.strftime('%H:%M:%S'), "Sleeping and stuck in not so infinite while loop"
+                print(time.strftime('%H:%M:%S'), "Sleeping and stuck in not so infinite while loop")
             self.waitSecond += 1
             time.sleep(1)
 
-        print time.strftime('%H:%M:%S'), "Received", self.nMessagesReceived, "messages"
+        print(time.strftime('%H:%M:%S'), "Received", self.nMessagesReceived, "messages")
 
     def stop(self):
-        print "Stopping"
+        print("Stopping")
         self.stopped = True
         self.qs.close()
 
 
 def main():
-    print "Starting up at", time.strftime('%H:%M:%S')
+    print("Starting up at", time.strftime('%H:%M:%S'))
 
     topic = 'edex.alerts'
     host = 'localhost'
